<?php

namespace App\Http\Controllers\Dashboard\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\LoginRequest;
use Illuminate\Contracts\Foundation\Application;
use Illuminate\Contracts\View\Factory;
use Illuminate\Contracts\View\View;
use Illuminate\Http\RedirectResponse;
use Illuminate\Support\Facades\Auth;

class LoginController extends Controller
{
  /**
   * Show the login form.
   *
   * @return Application|Factory|View
   */
  public function showLoginForm(): View
  {
    return view('content.authentications.auth-login-basic')->with('success', 'Toast notification has been set.');
  }

  /**
   * Handle an authentication attempt.
   *
   * @param LoginRequest $request
   * @return RedirectResponse
   */
  public function login(LoginRequest $request): RedirectResponse
  {
    $credentials = $this->getCredentials($request);

    if (Auth::guard('admin')->attempt($credentials)) {
      $request->session()->regenerate();

      return redirect()->intended('dashboard');
    }

    return back()->withErrors([
      'username' => 'The provided credentials do not match our records.',
    ])->onlyInput('username');
  }

  /**
   * Get the login credentials based on the request input.
   *
   * @param LoginRequest $request
   * @return array
   */
  protected function getCredentials(LoginRequest $request): array
  {
    return [
      $request->validated()['username_type'] => $request->validated()['username'],
      'password' => $request->validated()['password'],
    ];
  }
}
