<?php

namespace App\Livewire;

use App\Models\Admin;
use Illuminate\Support\Carbon;
use Illuminate\Database\Eloquent\Builder;
use PowerComponents\LivewirePowerGrid\Button;
use PowerComponents\LivewirePowerGrid\Column;
use PowerComponents\LivewirePowerGrid\Exportable;
use PowerComponents\LivewirePowerGrid\Facades\Filter;
use PowerComponents\LivewirePowerGrid\Footer;
use PowerComponents\LivewirePowerGrid\Header;
use PowerComponents\LivewirePowerGrid\PowerGrid;
use PowerComponents\LivewirePowerGrid\PowerGridFields;
use PowerComponents\LivewirePowerGrid\PowerGridComponent;
use PowerComponents\LivewirePowerGrid\Traits\WithExport;

final class AdminTable extends PowerGridComponent
{
  use WithExport;

  public function setUp(): array
  {
    $this->showCheckBox();

    return [
      Exportable::make('export')
        ->striped()
        ->type(Exportable::TYPE_XLS, Exportable::TYPE_CSV),
      Footer::make()
        ->showPerPage()
        ->showPerPage(perPage: 15, perPageValues: [0, 15, 30, 50,100, 500])
        ->showRecordCount(),
      Header::make()
        ->showSearchInput()
        ->showSoftDeletes(showMessage: true),
    ];
  }

  public function datasource(): Builder
  {
    return Admin::query();
  }

  public function relationSearch(): array
  {
    return [];
  }

  public function fields(): PowerGridFields
  {
    return PowerGrid::fields()
      ->add('id')
      ->add('name')
      ->add('email')
      ->add('username')
      ->add('phone')
      ->add('active')
      ->add('created_at');
  }

  public function columns(): array
  {
    return [
      Column::make('Id', 'id'),
      Column::make('Name', 'name')
        ->sortable()
        ->searchable(),

      Column::make('Email', 'email')
        ->sortable()
        ->searchable(),

      Column::make('Username', 'username')
        ->sortable()
        ->searchable()->editOnClick(),

      Column::make('Phone', 'phone')
        ->sortable()
        ->searchable()
      ,


      Column::add()
        ->title('is Active')
        ->field('active')
        ->toggleable(),

      Column::make('Created at', 'created_at')
        ->sortable()
        ->searchable(),

      Column::action('Action')
    ];
  }

  public function filters(): array
  {
    return [
      Filter::inputText('name')
        ->operators(['contains', 'starts_with', 'ends_with'])
        ->placeholder('Search by Name'),

      Filter::inputText('email')

        ->placeholder('Search by Email'),

      Filter::inputText('username')
        ->operators(['contains', 'starts_with', 'ends_with'])
        ->placeholder('Search by Username'),

      Filter::inputText('phone')
        ->operators(['contains', 'starts_with', 'ends_with'])
        ->placeholder('Search by Phone'),

      Filter::boolean('active')
        ->label('yes', 'no'),

      Filter::datepicker('created_at', 'created_at'),

    ];
  }


  #[\Livewire\Attributes\On('edit')]
  public function edit($rowId): void
  {
    $this->js('alert(' . $rowId . ')');
  }

  public function actions(Admin $row): array
  {
    return [
      Button::add('edit')
        ->slot('Edit: ' . $row->id)
        ->id()
        ->class('pg-btn-white dark:ring-pg-primary-600 dark:border-pg-primary-600 dark:hover:bg-pg-primary-700 dark:ring-offset-pg-primary-800 dark:text-pg-primary-300 dark:bg-pg-primary-700')
        ->dispatch('edit', ['rowId' => $row->id])
    ];
  }

  public function onUpdatedToggleable(string|int $id, string $field, string $value): void
  {
    Admin::query()->find($id)->update([
      $field => e($value),
    ]);
  }

  public function onUpdatedEditable(string|int $id, string $field, string $value): void
  {
    Admin::query()->find($id)->update([
      $field => e($value),
    ]);
  }

  /*
  public function actionRules($row): array
  {
     return [
          // Hide button edit for ID 1
          Rule::button('edit')
              ->when(fn($row) => $row->id === 1)
              ->hide(),
      ];
  }
  */
}
