<?php

use App\Http\Controllers\Dashboard\Auth\LoginController;
use App\Http\Controllers\Dashboard\Auth\LogOutController;
use App\Http\Controllers\Dashboard\Roles\ListRolesController;
use App\Http\Controllers\Dashboard\Roles\SaveRolesController;
use App\Http\Controllers\pages\HomePage;
use App\Http\Middleware\EnsureAdminIsAuthenticated;
use App\Http\Middleware\RedirectIfAdminAuthenticated;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\language\LanguageController;
use App\Http\Controllers\pages\MiscError;
use App\Http\Controllers\pages\Page2;

/*
|--------------------------------------------------------------------------
| Admin Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Route for language swapping
Route::get('lang/{locale}', [LanguageController::class, 'swap'])->name('language.swap');

// Group routes under 'dashboard' prefix
Route::prefix('dashboard')->name('dashboard.')->group(function () {

  // Routes for guests (not authenticated)
  Route::middleware([RedirectIfAdminAuthenticated::class])->group(function () {
    Route::get('/login', [LoginController::class, 'showLoginForm'])->name('admin.login.form');
    Route::post('/login', [LoginController::class, 'login'])->name('admin.login.submit');
  });

  // Route for saving roles
  Route::post('/roles', SaveRolesController::class)->name('roles.save');

  // Routes for authenticated admins
  Route::middleware([EnsureAdminIsAuthenticated::class])->group(function () {
    Route::post('/logout', [LogOutController::class, 'logout'])->name('admin.logout');

    Route::get('/', [HomePage::class, 'index'])->name('home');

    Route::get('/roles', ListRolesController::class)->name('roles.list');

    Route::get('/page-2', [Page2::class, 'index'])->name('page2.index');
    Route::get('/pages/misc-error', [MiscError::class, 'index'])->name('pages.miscError');
  });
});
